@@ -54,32 +54,36 @@ struct _SeahorseContextClass
 {
 	GtkObjectClass		parent_class;
 	
-	/* Signal emitted to show the status of an operation */
-	void 			(* status)			(const SeahorseContext	*sctx,
-								 const gchar		*op);
-	
 	/* Signal emitted when @skey has been added to @sctx */
 	void 			(* add)				(SeahorseContext	*sctx,
 								 SeahorseKey		*skey);
+	
+	/* Signal emitted while an operation is in progress */
+	void			(* progress)			(SeahorseContext	*sctx,
+								 const gchar		*op,
+								 gdouble		fract);
 };
 
 SeahorseContext*	seahorse_context_new			(void);
 
 void			seahorse_context_destroy		(SeahorseContext	*sctx);
 
-GList*			seahorse_context_get_keys		(const SeahorseContext	*sctx);
+GList*			seahorse_context_get_keys		(SeahorseContext	*sctx);
 
-void			seahorse_context_show_status		(const SeahorseContext	*sctx,
-								 const gchar		*op,
-								 gboolean		success);
+GList*			seahorse_context_get_key_pairs		(SeahorseContext	*sctx);
+
+SeahorseKey*		seahorse_context_get_key		(SeahorseContext	*sctx,
+								 GpgmeKey		key);
 
 void			seahorse_context_key_added		(SeahorseContext	*sctx);
 
-SeahorseKey*		seahorse_context_get_key		(const SeahorseContext	*sctx,
-								 GpgmeKey		key);
+void			seahorse_context_show_status		(SeahorseContext	*sctx,
+								 const gchar		*op,
+								 gboolean		success);
 
-gboolean		seahorse_context_key_has_secret		(SeahorseContext	*sctx,
-								 SeahorseKey		*skey);
+void			seahorse_context_show_progress		(SeahorseContext	*sctx,
+								 const gchar		*op,
+								 gdouble		fract);
 
 void			seahorse_context_set_ascii_armor	(SeahorseContext	*sctx,
 								 gboolean		ascii_armor);
@@ -90,6 +94,8 @@ void			seahorse_context_set_text_mode		(SeahorseContext	*sctx,
 void			seahorse_context_set_signer		(SeahorseContext	*sctx,
 								 SeahorseKey		*signer);
 
-SeahorseKey*		seahorse_context_get_last_signer	(const SeahorseContext	*sctx);
+SeahorseKey*		seahorse_context_get_last_signer	(SeahorseContext	*sctx);
+
+gint			seahorse_context_get_progress_update	(SeahorseContext	*sctx);
 
 #endif /* __SEAHORSE_CONTEXT_H__ */
