@@ -26,12 +26,9 @@
 #include "seahorse-key-properties.h"
 #include "seahorse-key-widget.h"
 #include "seahorse-util.h"
-#include "seahorse-export.h"
-#include "seahorse-delete.h"
 #include "seahorse-validity.h"
-#include "seahorse-add-uid.h"
-#include "seahorse-add-subkey.h"
-#include "seahorse-revoke.h"
+#include "seahorse-key-dialogs.h"
+#include "seahorse-key-pair.h"
 
 #define SPACING 12
 #define TRUST "trust"
@@ -47,12 +44,18 @@ export_activate (GtkWidget *widget, SeahorseWidget *swidget)
 	seahorse_export_new (swidget->sctx, SEAHORSE_KEY_WIDGET (swidget)->skey);
 }
 
+static void
+sign_activate (GtkWidget *widget, SeahorseWidget *swidget)
+{
+	seahorse_sign_new (swidget->sctx, SEAHORSE_KEY_WIDGET (swidget)->skey, 0);
+}
+
 /* Loads delete dialog */
 static void
 delete_activate (GtkWidget *widget, SeahorseWidget *swidget)
 {
-	seahorse_delete_key_new (NULL, swidget->sctx,
-		SEAHORSE_KEY_WIDGET (swidget)->skey);
+	seahorse_delete_new (swidget->sctx,
+		SEAHORSE_KEY_WIDGET (swidget)->skey, 0);
 }
 
 /* Tries to change the key's owner trust */
@@ -141,6 +144,12 @@ add_subkey_activate (GtkMenuItem *item, SeahorseWidget *swidget)
 	seahorse_add_subkey_new (swidget->sctx, SEAHORSE_KEY_WIDGET (swidget)->skey);
 }
 
+static void
+add_revoker_activate (GtkMenuItem *item, SeahorseWidget *swidget)
+{
+	seahorse_add_revoker_new (swidget->sctx, SEAHORSE_KEY_WIDGET (swidget)->skey);
+}
+
 static void
 subkeys_activate (GtkMenuItem *item, SeahorseWidget *swidget)
 {
@@ -158,8 +167,7 @@ del_subkey_clicked (GtkButton *button, SeahorseWidget *swidget)
 	index = gtk_notebook_get_current_page (GTK_NOTEBOOK (
 		glade_xml_get_widget (swidget->xml, SUBKEYS))) + 1;
 	
-	seahorse_delete_subkey_new (GTK_WINDOW (glade_xml_get_widget (
-		swidget->xml, swidget->name)), swidget->sctx,
+	seahorse_delete_new (swidget->sctx,
 		SEAHORSE_KEY_WIDGET (swidget)->skey, index);
 }
 
@@ -170,12 +178,12 @@ revoke_subkey_clicked (GtkButton *button, SeahorseWidget *swidget)
 	
 	index = gtk_notebook_get_current_page (GTK_NOTEBOOK (
 		glade_xml_get_widget (swidget->xml, SUBKEYS))) + 1;
-	seahorse_revoke_subkey_new (swidget->sctx,
+	seahorse_revoke_new (swidget->sctx,
 		SEAHORSE_KEY_WIDGET (swidget)->skey, index);
 }
 
 /* Do a label */
-static void
+static GtkWidget*
 do_stat_label (const gchar *label, GtkTable *table, guint left, guint top)
 {
 	GtkWidget *widget;
@@ -187,6 +195,8 @@ do_stat_label (const gchar *label, GtkTable *table, guint left, guint top)
 	gtk_container_add (GTK_CONTAINER (align), widget);
 	gtk_table_attach (table, align, left, left+1, top, top+1, GTK_FILL, 0, 0, 0);
 	gtk_widget_show_all (align);
+	
+	return widget;
 }
 
 /* Do statistics common to primary and sub keys */
@@ -201,7 +211,8 @@ do_stats (SeahorseWidget *swidget, GtkTable *table, guint top, guint index)
 	skey = SEAHORSE_KEY_WIDGET (swidget)->skey;
 	tooltips = gtk_tooltips_new ();
 	
-	do_stat_label (_("Key ID:"), table, 0, top);
+	widget = do_stat_label (_("Key ID:"), table, 0, top);
+	gtk_label_set_selectable (GTK_LABEL (widget), TRUE);
 	do_stat_label (seahorse_key_get_keyid (skey, index), table, 1, top);
 	do_stat_label (_("Type:"), table, 2, top);
 	do_stat_label (gpgme_key_get_string_attr (skey->key, GPGME_ATTR_ALGO, NULL, index), table, 3, top);
@@ -215,7 +226,7 @@ do_stats (SeahorseWidget *swidget, GtkTable *table, guint top, guint index)
 	
 	expires = gpgme_key_get_ulong_attr (skey->key, GPGME_ATTR_EXPIRE, NULL, index);
 	
-	if (!seahorse_context_key_has_secret (swidget->sctx, skey)) {
+	if (!SEAHORSE_IS_KEY_PAIR (skey)) {
 		if (expires)
 			do_stat_label (seahorse_util_get_date_string (expires), table, 1, top+2);
 		else
@@ -278,7 +289,7 @@ do_uids (SeahorseWidget *swidget)
 	tooltips = gtk_tooltips_new ();
 	
 	while (index < max) {
-		if (max > 1 && seahorse_context_key_has_secret (swidget->sctx, skwidget->skey)) {
+		if (max > 1 && SEAHORSE_IS_KEY_PAIR (skwidget->skey)) {
 			table = GTK_TABLE (gtk_table_new (2, 2, FALSE));
 			
 			widget = gtk_radio_button_new_with_mnemonic (group, _("_Primary"));
@@ -338,20 +349,9 @@ do_subkeys (SeahorseWidget *swidget)
 		gtk_widget_show (widget);
 	
 	while (index <= max) {
-		if (seahorse_context_key_has_secret (swidget->sctx, skwidget->skey)) {
+		if (SEAHORSE_IS_KEY_PAIR (skwidget->skey)) {
 			table = GTK_TABLE (gtk_table_new (4, 4, FALSE));
 			
-			do_stat_label (_("Status:"), table, 0, 3);
-			
-			if (gpgme_key_get_ulong_attr (skwidget->skey->key,
-			GPGME_ATTR_KEY_REVOKED, NULL, index))
-				do_stat_label (_("Revoked"), table, 1, 3);
-			else if (gpgme_key_get_ulong_attr (skwidget->skey->key,
-			GPGME_ATTR_KEY_EXPIRED, NULL, index))
-				do_stat_label (_("Expired"), table, 1, 3);
-			else
-				do_stat_label (_("Good"), table, 1, 3);
-			
 			/* Do revoke button */
 			if (!gpgme_key_get_ulong_attr (skwidget->skey->key,
 			GPGME_ATTR_KEY_REVOKED, NULL, index)) {
@@ -376,27 +376,9 @@ do_subkeys (SeahorseWidget *swidget)
 				gtk_widget_show_all (button);
 				gtk_table_attach (table, button, 2, 3, 3, 4, GTK_FILL, 0, 0, 0);
 			}
-			
-			/* Do delete button */
-			widget = gtk_button_new_from_stock (GTK_STOCK_DELETE);
-			g_signal_connect_after (GTK_BUTTON (widget), "clicked",
-				G_CALLBACK (del_subkey_clicked), swidget);
-			gtk_widget_show (widget);
-			gtk_table_attach (table, widget, 3, 4, 3, 4, GTK_FILL, 0, 0, 0);
 		}
-		else {
+		else
 			table = GTK_TABLE (gtk_table_new (3, 4, FALSE));
-			do_stat_label (_("Status:"), table, 2, 2);
-			
-			if (gpgme_key_get_ulong_attr (skwidget->skey->key,
-			GPGME_ATTR_KEY_REVOKED, NULL, index))
-				do_stat_label (_("Revoked"), table, 3, 2);
-			else if (gpgme_key_get_ulong_attr (skwidget->skey->key,
-			GPGME_ATTR_KEY_EXPIRED, NULL, index))
-				do_stat_label (_("Expired"), table, 3, 2);
-			else
-				do_stat_label (_("Good"), table, 3, 2);
-		}
 		
 		gtk_table_set_row_spacings (table, SPACING);
 		gtk_table_set_col_spacings (table, SPACING);
@@ -408,6 +390,22 @@ do_subkeys (SeahorseWidget *swidget)
 		
 		do_stats (swidget, table, 0, index);
 		
+		/* do status */
+		do_stat_label (_("Status:"), table, 0, 3);
+		if (gpgme_key_get_ulong_attr (skwidget->skey->key, GPGME_ATTR_KEY_REVOKED, NULL, index))
+			do_stat_label (_("Revoked"), table, 1, 3);
+		else if (gpgme_key_get_ulong_attr (skwidget->skey->key, GPGME_ATTR_KEY_EXPIRED, NULL, index))
+			do_stat_label (_("Expired"), table, 1, 3);
+		else
+			do_stat_label (_("Good"), table, 1, 3);
+		
+		/* Do delete button */
+		widget = gtk_button_new_from_stock (GTK_STOCK_DELETE);
+		g_signal_connect_after (GTK_BUTTON (widget), "clicked",
+			G_CALLBACK (del_subkey_clicked), swidget);
+		gtk_widget_show (widget);
+		gtk_table_attach (table, widget, 3, 4, 3, 4, GTK_FILL, 0, 0, 0);
+		
 		index++;
 	}
 }
@@ -446,9 +444,11 @@ seahorse_key_properties_new (SeahorseContext *sctx, SeahorseKey *skey)
 	g_return_if_fail (swidget != NULL);
 	
 	/* Hide edit menu if key doesn't have secret component */
-	if (!seahorse_context_key_has_secret (sctx, skey)) {
-		widget = glade_xml_get_widget (swidget->xml, "edit_menu");
-		gtk_widget_hide (widget);
+	if (!SEAHORSE_IS_KEY_PAIR(skey)) {
+		gtk_widget_set_sensitive (glade_xml_get_widget (swidget->xml, "change_passphrase"), FALSE);
+		gtk_widget_set_sensitive (glade_xml_get_widget (swidget->xml, "add_uid"), FALSE);
+		gtk_widget_set_sensitive (glade_xml_get_widget (swidget->xml, "add_subkey"), FALSE);
+		gtk_widget_set_sensitive (glade_xml_get_widget (swidget->xml, "add_revoker"), FALSE);
 	}
 	
 	/* Primary key attributes */
@@ -472,6 +472,8 @@ seahorse_key_properties_new (SeahorseContext *sctx, SeahorseKey *skey)
 	
 	glade_xml_signal_connect_data (swidget->xml, "export_activate",
 		G_CALLBACK (export_activate), swidget);
+	glade_xml_signal_connect_data (swidget->xml, "sign_activate",
+		G_CALLBACK (sign_activate), swidget);
 	glade_xml_signal_connect_data (swidget->xml, "delete_activate",
 		G_CALLBACK (delete_activate), swidget);
 	glade_xml_signal_connect_data (swidget->xml, "trust_changed",
@@ -484,8 +486,12 @@ seahorse_key_properties_new (SeahorseContext *sctx, SeahorseKey *skey)
 		G_CALLBACK (add_uid_activate), swidget);
 	glade_xml_signal_connect_data (swidget->xml, "add_subkey_activate",
 		G_CALLBACK (add_subkey_activate), swidget);
+	glade_xml_signal_connect_data (swidget->xml, "add_revoker_activate",
+		G_CALLBACK (add_revoker_activate), swidget);
 	glade_xml_signal_connect_data (swidget->xml, "subkeys_activate",
 		G_CALLBACK (subkeys_activate), swidget);
 	
 	g_signal_connect_after (skey, "changed", G_CALLBACK (key_changed), swidget);
+	
+	gtk_widget_set_sensitive (glade_xml_get_widget (swidget->xml, "add_photo"), FALSE);
 }
